@@ -63,7 +63,13 @@ class Alarms:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Alarms.__init__)
+            def stub(
+                *,
+                lower_alarm_interval_index: typing.Optional[jsii.Number] = None,
+                upper_alarm_interval_index: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument lower_alarm_interval_index", value=lower_alarm_interval_index, expected_type=type_hints["lower_alarm_interval_index"])
             check_type(argname="argument upper_alarm_interval_index", value=upper_alarm_interval_index, expected_type=type_hints["upper_alarm_interval_index"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -130,7 +136,13 @@ class ArbitraryIntervals:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ArbitraryIntervals.__init__)
+            def stub(
+                *,
+                absolute: builtins.bool,
+                intervals: typing.Sequence[typing.Union["ScalingInterval", typing.Dict[str, typing.Any]]],
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument absolute", value=absolute, expected_type=type_hints["absolute"])
             check_type(argname="argument intervals", value=intervals, expected_type=type_hints["intervals"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -197,7 +209,14 @@ class CompleteScalingInterval:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CompleteScalingInterval.__init__)
+            def stub(
+                *,
+                lower: jsii.Number,
+                upper: jsii.Number,
+                change: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument lower", value=lower, expected_type=type_hints["lower"])
             check_type(argname="argument upper", value=upper, expected_type=type_hints["upper"])
             check_type(argname="argument change", value=change, expected_type=type_hints["change"])
@@ -266,7 +285,9 @@ class _IRandomGeneratorProxy:
         :param max: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IRandomGenerator.next_int)
+            def stub(min: jsii.Number, max: jsii.Number) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument min", value=min, expected_type=type_hints["min"])
             check_type(argname="argument max", value=max, expected_type=type_hints["max"])
         return typing.cast(jsii.Number, jsii.invoke(self, "nextInt", [min, max]))
@@ -311,7 +332,14 @@ class ScalingInterval:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ScalingInterval.__init__)
+            def stub(
+                *,
+                change: jsii.Number,
+                lower: typing.Optional[jsii.Number] = None,
+                upper: typing.Optional[jsii.Number] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument change", value=change, expected_type=type_hints["change"])
             check_type(argname="argument lower", value=lower, expected_type=type_hints["lower"])
             check_type(argname="argument upper", value=upper, expected_type=type_hints["upper"])
